# Invoker Readme
invoker utility for DI(Injector) and context configuration.

## How to use
```sh
cd sample
invoker logging.yaml invoke_option.yaml \
  --config config_base.yaml \
  --config config_diff.yaml
```